#!/bin/bash
#
# File:  xray-example.sh
# Date:  23-Sept-2016  Jdw
#
SLEEP=2
THISDIR="$( builtin cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
#
# Handle optional arguments from the environment and add a unique session file
#
TS=`/bin/date "+%Y%m%d%H%M%S"`_$$
if [  -n "${ONEDEP_EXTRA_ARGS}" ]
then
    X_ARGS="${ONEDEP_EXTRA_ARGS} --session_file ./.onedep_session_${TS} "
else
    X_ARGS=" --session_file ./.onedep_session_${TS} "
fi
#
# New session  -
#
onedep_validate_cli --new_session ${X_ARGS}
#
# Upload input files -
onedep_validate_cli --input_file  ${THISDIR}/data/1cbs.cif.gz     --input_type model              ${X_ARGS}
onedep_validate_cli --input_file  ${THISDIR}/data/1cbs-sf.cif.gz  --input_type structure-factors  ${X_ARGS}
#
# Submit request to run validation service
onedep_validate_cli --validate ${X_ARGS}
#
# Poll for completion status
#
STEP=0
while :
do
   STEP=$((STEP + 1))
   PAUSE=$((STEP * STEP * SLEEP))
   echo "[${STEP}] Pausing for ${PAUSE} seconds.   Press CTRL+C to stop..."
   sleep ${PAUSE}
   ST=$(onedep_validate_cli --test_complete ${X_ARGS})
   #
   if [ "${ST}" == "1" ]
   then
        break #Abandon the loop.
   fi
done
#
#  Optionally, check the completion status
onedep_validate_cli --status ${X_ARGS}
#
#  Get an index of output report files
onedep_validate_cli --index  ${X_ARGS}
#
#  Download report (by file type)
onedep_validate_cli --output_file 1cbs-report-${TS}.pdf  --output_type validation-report-full  ${X_ARGS}
onedep_validate_cli --output_file 1cbs-report-${TS}.xml  --output_type validation-data         ${X_ARGS}
onedep_validate_cli --output_file 1cbs-report-${TS}.log  --output_type validation-report-log   ${X_ARGS}
#
#  Get a summary of service activity -
# onedep_validate_cli --activity ${X_ARGS}
#
